@@ -303,17 +303,9 @@ class MediaPlayer2Service(Server):
         except:
             pass
 
-        try:
-            album = media.get_album()
-            assert album is not None
-        except:
-            try:
-                album = media.get_album()
-                assert album is not None
-            except:
-                album = _("Unknown Album")
-        finally:
-            metadata['xesam:album'] = GLib.Variant('s', album)
+
+        album = utils.get_album_title(media)
+        metadata['xesam:album'] = GLib.Variant('s', album)
 
         artist = utils.get_artist_name(media)
         metadata['xesam:artist'] = GLib.Variant('as', [artist])
@@ -392,10 +384,7 @@ class MediaPlayer2Service(Server):
             else:
                 callback(playlists)
 
-        if grilo.tracker:
-            GLib.idle_add(grilo.populate_playlists, 0, populate_callback)
-        else:
-            callback(playlists)
+        grilo.populate_playlists(0, populate_callback)
 
     @log
     def _get_active_playlist(self):
